pub enum Sdk {
Dlss,
Nrd,
Omm,
Sharc,
Streamline,
}Expand description
A supported NVIDIA SDK integration.
Variants
Implementations
Sourceimpl Sdk
impl Sdk
pub const fn name(self) -> &'static str
Sourcepub fn resolve(self, options: &ResolveOptions) -> Result<ResolvedSdk>
pub fn resolve(self, options: &ResolveOptions) -> Result<ResolvedSdk>
Resolves and validates this SDK for one target.
Errors
Returns an error if the target is unsupported, a configured SDK is invalid, or a required archive cannot be securely acquired and validated.