pub struct ResolvedSdk {
pub artifact: String,
pub license: String,
pub license_url: String,
pub path: PathBuf,
pub sdk: Sdk,
pub source_url: Option<String>,
pub target: String,
pub version: String,
}Expand description
A validated SDK tree and its pinned provenance.
Fields
artifact: Stringlicense: Stringlicense_url: Stringpath: PathBufsdk: Sdksource_url: Option<String>target: Stringversion: StringImplementations
Sourceimpl ResolvedSdk
impl ResolvedSdk
Sourcepub fn stage_runtime(
&self,
output: &Path,
profile: RuntimeProfile,
) -> Result<Vec<StagedFile>>
pub fn stage_runtime( &self, output: &Path, profile: RuntimeProfile, ) -> Result<Vec<StagedFile>>
Copies this SDK’s selected redistributable runtime set into output.
Errors
Returns an error if the resolved artifact has no runtime manifest or a required file cannot be copied safely.